package #
Date::Manip::Offset::off389;
# Copyright (c) 2008-2019 Sullivan Beck.  All rights reserved.
# This program is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.

# This file was automatically generated.  Any changes to this file will
# be lost the next time 'tzdata' is run.
#    Generated on: Thu Feb 28 13:08:01 EST 2019
#    Data version: tzdata2018i
#    Code version: tzcode2018i

# This module contains data from the zoneinfo time zone database.  The original
# data was obtained from the URL:
#    ftp://ftp.iana.org/tz

use strict;
use warnings;
require 5.010000;

our ($VERSION);
$VERSION='6.76';
END { undef $VERSION; }

our ($Offset,%Offset);
END {
   undef $Offset;
   undef %Offset;
}

$Offset        = '-07:00:00';

%Offset        = (
   0 => [
      'america/denver',
      'america/phoenix',
      'america/creston',
      'america/edmonton',
      'america/cambridge_bay',
      'america/chihuahua',
      'america/hermosillo',
      'america/mazatlan',
      'america/ojinaga',
      'america/boise',
      'america/yellowknife',
      'america/dawson_creek',
      'america/inuvik',
      'america/fort_nelson',
      'etc/gmt-7',
      'g',
      'america/north_dakota/beulah',
      'america/bahia_banderas',
      'america/north_dakota/new_salem',
      'america/north_dakota/center',
      'pacific/easter',
      'america/swift_current',
      'america/regina',
      'america/mexico_city',
      'america/tijuana',
      ],
   1 => [
      'america/los_angeles',
      'america/vancouver',
      'america/tijuana',
      'america/dawson',
      'america/whitehorse',
      'america/fort_nelson',
      'america/juneau',
      'america/metlakatla',
      'america/sitka',
      'america/dawson_creek',
      'america/boise',
      ],
);

1;
